create a super simple aggregation feature that sums up the number of daily transactions for a given merchant. assume the raw data can be found in Snowflake. Use SparkSQL.

create an aggregation feature that sums up the number of transactions for a given merchant in the last 5 minutes

